from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class EraseUserSubscriptionAccount(BaseModel):
    subscription_id: Optional[str] = None
    child_user_access_id: Optional[str] = None


EraseUserSubscriptionAccount.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class GlobalTemplateRecentDeployments(BaseModel):
    new_inherited_templates_count: Optional[int] = None
    new_content_fields_count: Optional[int] = None


GlobalTemplateRecentDeployments.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.app import App
from pianosdk.publisher.models.external_api_field import ExternalAPIField
from pianosdk.publisher.models.external_api_provider_property import ExternalAPIProviderProperty
from pianosdk.publisher.models.term import Term
from typing import List


class ExternalAPIConfiguration(BaseModel):
    external_api_id: Optional[str] = None
    name: Optional[str] = None
    app: Optional['App'] = None
    form_fields: Optional['List[ExternalAPIField]'] = None
    properties: Optional['List[ExternalAPIProviderProperty]'] = None
    provider: Optional[str] = None
    description: Optional[str] = None
    terms: Optional['List[Term]'] = None
    enforce_uniqueness: Optional[bool] = None
    can_update_fields: Optional[bool] = None
    force_grace_period: Optional[int] = None
    external_api_source_id: Optional[int] = None
    default_verification_period: Optional[int] = None


ExternalAPIConfiguration.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TaxProductCategory(BaseModel):
    caption: Optional[str] = None
    code: Optional[str] = None
    name: Optional[str] = None


TaxProductCategory.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.user import User


class UpgradeCheckoutFlow(BaseModel):
    checkout_flow_id: Optional[str] = None
    name: Optional[str] = None
    checkout_flow_type: Optional[str] = None
    description: Optional[str] = None
    create_date: Optional[datetime] = None
    create_by: Optional['User'] = None
    update_date: Optional[datetime] = None
    update_by: Optional['User'] = None
    deleted: Optional[bool] = None
    billing_timing: Optional[str] = None
    immediate_access: Optional[bool] = None
    prorate_access: Optional[bool] = None


UpgradeCheckoutFlow.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from typing import Any
from typing import Dict
from typing import List


class CreateLinkedTermRequest(BaseModel):
    aid: Optional[str] = None
    external_term_id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    subscription_management_url: Optional[str] = None
    external_product_ids: Optional[str] = None
    custom_data: Optional['Dict[str, Any]'] = None


CreateLinkedTermRequest.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class Currency(BaseModel):
    currency_code: Optional[str] = None
    currency_symbol: Optional[str] = None


Currency.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class GlobalTemplateFilterSubItem(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    counter_value: Optional[int] = None


GlobalTemplateFilterSubItem.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TermShort(BaseModel):
    term_id: Optional[str] = None
    name: Optional[str] = None
    term_name: Optional[str] = None
    disabled: Optional[bool] = None
    tooltip: Optional[str] = None
    variant_type: Optional[str] = None
    period_id: Optional[str] = None
    period_name: Optional[str] = None


TermShort.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.term import Term


class PublisherTermApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def applicable(self, aid: str, promotion_id: str = None, q: str = None, order_by: str = None, order_direction: str = None) -> ApiResponse[List[Term]]:
        _url_path = '/api/v3/publisher/term/applicable'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'promotion_id': _encode_parameter(promotion_id),
            'aid': _encode_parameter(aid),
            'q': _encode_parameter(q),
            'order_by': _encode_parameter(order_by),
            'order_direction': _encode_parameter(order_direction)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Term)
        return _result

    def count(self, aid: str, include_type: List[str] = None, exclude_type: List[str] = None, term_id: str = None, resource_type: str = None, source: List[str] = None, type: str = None) -> ApiResponse[int]:
        _url_path = '/api/v3/publisher/term/count'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'include_type': _encode_parameter(include_type),
            'exclude_type': _encode_parameter(exclude_type),
            'term_id': _encode_parameter(term_id),
            'resource_type': _encode_parameter(resource_type),
            'source': _encode_parameter(source),
            'type': _encode_parameter(type)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, int)
        return _result

    def delete(self, term_id: str) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/term/delete'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'term_id': _encode_parameter(term_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def get(self, term_id: str) -> ApiResponse[Term]:
        _url_path = '/api/v3/publisher/term/get'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'term_id': _encode_parameter(term_id)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Term)
        return _result

    def list(self, aid: str, offset: int = 0, limit: int = 100, rid: str = None, include_type: List[str] = None, exclude_type: List[str] = None, term_id: str = None, resource_type: str = None, source: List[str] = None, type: str = None, order_by: str = None, order_direction: str = None, q: str = None) -> ApiResponse[List[Term]]:
        _url_path = '/api/v3/publisher/term/list'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid),
            'include_type': _encode_parameter(include_type),
            'exclude_type': _encode_parameter(exclude_type),
            'term_id': _encode_parameter(term_id),
            'resource_type': _encode_parameter(resource_type),
            'source': _encode_parameter(source),
            'type': _encode_parameter(type),
            'order_by': _encode_parameter(order_by),
            'order_direction': _encode_parameter(order_direction),
            'offset': _encode_parameter(offset),
            'limit': _encode_parameter(limit),
            'q': _encode_parameter(q)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Term)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class EraseUserPayment(BaseModel):
    user_payment_id: Optional[str] = None
    tax: Optional[str] = None
    billing_region: Optional[str] = None
    residence_region: Optional[str] = None
    ui_caption: Optional[str] = None
    name: Optional[str] = None
    address: Optional[str] = None
    geo_location_country: Optional[str] = None
    geo_location: Optional[str] = None


EraseUserPayment.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.erase_contract_user import EraseContractUser
from pianosdk.publisher.models.erase_conversion import EraseConversion
from pianosdk.publisher.models.erase_subscription import EraseSubscription
from pianosdk.publisher.models.erase_transaction import EraseTransaction
from pianosdk.publisher.models.erase_user import EraseUser
from pianosdk.publisher.models.erase_user_address import EraseUserAddress
from pianosdk.publisher.models.erase_user_payment import EraseUserPayment
from pianosdk.publisher.models.erase_user_payment_info import EraseUserPaymentInfo
from pianosdk.publisher.models.erase_user_subscription_account import EraseUserSubscriptionAccount
from typing import List


class EraseUserResponse(BaseModel):
    user: Optional['EraseUser'] = None
    addresses: Optional['List[EraseUserAddress]'] = None
    subscriptions: Optional['List[EraseSubscription]'] = None
    upis: Optional['List[EraseUserPaymentInfo]'] = None
    payments: Optional['List[EraseUserPayment]'] = None
    transactions: Optional['List[EraseTransaction]'] = None
    conversions: Optional['List[EraseConversion]'] = None
    contract_users: Optional['List[EraseContractUser]'] = None
    shared_accounts: Optional['List[EraseUserSubscriptionAccount]'] = None


EraseUserResponse.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.anon.models.term import Term


class UserSubscription(BaseModel):
    subscription_id: Optional[str] = None
    term: Optional['Term'] = None
    auto_renew: Optional[bool] = None
    grace_period_start_date: Optional[datetime] = None
    next_bill_date: Optional[datetime] = None
    start_date: Optional[datetime] = None
    create_date: Optional[datetime] = None
    status: Optional[str] = None
    cancelable: Optional[bool] = None
    cancelable_and_refundadle: Optional[bool] = None
    payment_billing_plan_description: Optional[str] = None
    external_sub_id: Optional[str] = None
    access_custom_data: Optional[str] = None


UserSubscription.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from typing import List


class MailOptionsVerificationResult(BaseModel):
    dkim: Optional[bool] = None
    dkim_tokens: Optional[List[str]] = None
    spf: Optional[bool] = None
    spf_record: Optional[str] = None
    txt: Optional[bool] = None
    txt_token: Optional[str] = None
    email_verify_status: Optional[str] = None
    verified_email: Optional[str] = None
    email_provider: Optional[str] = None
    email_domain_verified: Optional[bool] = None


MailOptionsVerificationResult.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ClientConfigurationsDto(BaseModel):
    ga_account: Optional[str] = None
    is_performance_metrics_enabled: Optional[str] = None
    performance_metrics_ga_account: Optional[str] = None
    performance_metrics_track_only_aids: Optional[str] = None
    msqa_client_id: Optional[str] = None


ClientConfigurationsDto.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class CustomFieldValueDto(BaseModel):
    field_name: Optional[str] = None
    value: Optional[str] = None
    created: Optional[datetime] = None
    email_creator: Optional[str] = None
    sort_order: Optional[int] = None


CustomFieldValueDto.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.anon.models.resource import Resource


class PasswordlessPurchaseCheckResult(BaseModel):
    poll_status: Optional[str] = None
    resource: Optional['Resource'] = None
    show_offer_params: Optional[str] = None
    type: Optional[str] = None


PasswordlessPurchaseCheckResult.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.churn_prevention_template_version import ChurnPreventionTemplateVersion
from typing import List


class ChurnPreventionEmail(BaseModel):
    email_id: Optional[int] = None
    email_name: Optional[str] = None
    template_id: Optional[str] = None
    versions: Optional['List[ChurnPreventionTemplateVersion]'] = None


ChurnPreventionEmail.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.country import Country
from pianosdk.publisher.models.region import Region
from pianosdk.publisher.models.user import User


class UserAddressHistory(BaseModel):
    create_date: Optional[datetime] = None
    update_date: Optional[datetime] = None
    revision: Optional[datetime] = None
    revision_type: Optional[int] = None
    user: Optional['User'] = None
    first_name: Optional[str] = None
    last_name: Optional[str] = None
    company_name: Optional[str] = None
    address1: Optional[str] = None
    address2: Optional[str] = None
    city: Optional[str] = None
    postal_code: Optional[str] = None
    phone: Optional[str] = None
    user_address_id: Optional[str] = None
    deleted: Optional[bool] = None
    region: Optional['Region'] = None
    additional_fields: Optional[str] = None
    country: Optional['Country'] = None
    update_by: Optional[str] = None
    create_by: Optional[str] = None


UserAddressHistory.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ContractDetails(BaseModel):
    contract_id: Optional[str] = None
    name: Optional[str] = None
    contract_type: Optional[str] = None
    contract_is_active: Optional[bool] = None
    contract_has_schedule: Optional[bool] = None
    seats_number: Optional[int] = None
    is_hard_seats_limit_type: Optional[bool] = None
    contract_allocated_users_count: Optional[int] = None
    contract_redeemed_users_count: Optional[int] = None
    create_date: Optional[datetime] = None
    end_date: Optional[datetime] = None


ContractDetails.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.error_code import ErrorCode
from typing import List


class ErrorCodes(BaseModel):
    errors: Optional['List[ErrorCode]'] = None
    error: Optional['ErrorCode'] = None


ErrorCodes.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class Mandate(BaseModel):
    id: Optional[str] = None
    reference: Optional[str] = None
    next_charge_date: Optional[datetime] = None


Mandate.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ImportDataState(BaseModel):
    import_data_id: Optional[str] = None
    import_data_status: Optional[str] = None


ImportDataState.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class LightOffer(BaseModel):
    offer_id: Optional[str] = None
    name: Optional[str] = None


LightOffer.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class SocialLinkResponse(BaseModel):
    uri: Optional[str] = None


SocialLinkResponse.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.user_billing_address import UserBillingAddress
from typing import Any
from typing import Dict
from typing import List


class PaymentMethodDTO(BaseModel):
    user_payment_info_id: Optional[str] = None
    description: Optional[str] = None
    upi_identifier: Optional[str] = None
    upi_nickname: Optional[str] = None
    upi_cardholder: Optional[str] = None
    upi_first_name: Optional[str] = None
    upi_last_name: Optional[str] = None
    upi_number: Optional[str] = None
    state: Optional[str] = None
    upi_expiration_month: Optional[int] = None
    upi_expiration_year: Optional[int] = None
    upi_postal_code: Optional[str] = None
    upi_email: Optional[str] = None
    upi_card_country_code: Optional[str] = None
    upi_card_zip_code: Optional[str] = None
    upi_country_state: Optional[str] = None
    upi_city: Optional[str] = None
    upi_street: Optional[str] = None
    currency: Optional[str] = None
    next_bill_date: Optional[str] = None
    readonly: Optional[bool] = None
    can_be_edited: Optional[bool] = None
    can_be_deleted: Optional[bool] = None
    can_be_set_default: Optional[bool] = None
    source_id: Optional[str] = None
    source_name: Optional[str] = None
    upi_ext_customer_id: Optional[str] = None
    upi_ext_customer_id_label: Optional[str] = None
    upi_ext_payment_id: Optional[str] = None
    tax_residence_country_code: Optional[str] = None
    tax_billing_country_code: Optional[str] = None
    tax_billing_zip_code: Optional[str] = None
    user_billing_address: Optional['UserBillingAddress'] = None
    stored_fields: Optional[str] = None
    payment_instrument_data: Optional['Dict[str, Any]'] = None


PaymentMethodDTO.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class AccessTokenList(BaseModel):
    value: Optional[str] = None
    cookie_domain: Optional[str] = None


AccessTokenList.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from typing import Any
from typing import Dict
from typing import List


class User(BaseModel):
    first_name: Optional[str] = None
    last_name: Optional[str] = None
    email: Optional[str] = None
    personal_name: Optional[str] = None
    uid: Optional[str] = None
    image1: Optional[str] = None
    create_date: Optional[datetime] = None
    reset_password_email_sent: Optional[bool] = None
    custom_fields: Optional['List[Dict[str, Any]]'] = None
    last_visit: Optional[datetime] = None
    last_login: Optional[datetime] = None
    display_name: Optional[str] = None


User.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class BillingPlanTranslationRequest(BaseModel):
    billing_plan: Optional[str] = None
    subscription_last_payment: Optional[datetime] = None
    start_date: Optional[datetime] = None
    end_date: Optional[datetime] = None
    term_pub_id: Optional[str] = None


BillingPlanTranslationRequest.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class Duration(BaseModel):
    value: Optional[int] = None
    unit: Optional[str] = None


Duration.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class Period(BaseModel):
    name: Optional[str] = None
    period_id: Optional[str] = None
    sell_date: Optional[datetime] = None
    begin_date: Optional[datetime] = None
    end_date: Optional[datetime] = None
    deleted: Optional[bool] = None
    create_date: Optional[datetime] = None
    update_date: Optional[datetime] = None
    is_sale_started: Optional[bool] = None
    is_active: Optional[bool] = None


Period.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.app import App
from pianosdk.publisher.models.user import User


class MailLog(BaseModel):
    email_id: Optional[str] = None
    app: Optional['App'] = None
    user: Optional['User'] = None
    sender: Optional[str] = None
    recipient: Optional[str] = None
    reply_to: Optional[str] = None
    create_date: Optional[str] = None
    open_date: Optional[str] = None
    status: Optional[str] = None
    status_localized: Optional[str] = None
    reject_reason: Optional[str] = None
    email_name: Optional[str] = None
    subject: Optional[str] = None
    body: Optional[str] = None


MailLog.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.target_term_change_variant import TargetTermChangeVariant
from typing import List


class TargetTermChangeVariants(BaseModel):
    eligible_options: Optional['List[TargetTermChangeVariant]'] = None
    ineligible_options: Optional['List[TargetTermChangeVariant]'] = None


TargetTermChangeVariants.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.app import App
from pianosdk.publisher.models.braintree_merchant_account_id_entry import BraintreeMerchantAccountIdEntry
from pianosdk.publisher.models.currency import Currency
from typing import List


class PaymentProviderConfiguration(BaseModel):
    configuration_id: Optional[str] = None
    app: Optional['App'] = None
    source_name: Optional[str] = None
    title: Optional[str] = None
    braintree_merchant_id: Optional[str] = None
    braintree_client_key: Optional[str] = None
    braintree_merchant_accounts: Optional['List[BraintreeMerchantAccountIdEntry]'] = None
    mock_currencies: Optional['List[Currency]'] = None
    is_disabled: Optional[bool] = None
    is_editable: Optional[bool] = None
    braintree_descriptor: Optional[str] = None
    braintree_trial_descriptor: Optional[str] = None
    is_visible: Optional[bool] = None


PaymentProviderConfiguration.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class SubscriptionUpgradeStatus(BaseModel):
    from_term_name: Optional[str] = None
    to_term_name: Optional[str] = None
    from_term_id: Optional[str] = None
    to_term_id: Optional[str] = None
    change_date: Optional[str] = None
    create_date_from: Optional[str] = None
    create_date_to: Optional[str] = None
    billing_plan_to: Optional[str] = None
    billing_plan_from: Optional[str] = None
    status: Optional[int] = None
    error_message: Optional[str] = None
    prorate_amount: Optional[str] = None
    prorate_refund_amount: Optional[str] = None


SubscriptionUpgradeStatus.model_rebuild()



from pianosdk.id.api.identity_oauth_api import IdentityOauthApi
from pianosdk.id.api.identity_token_api import IdentityTokenApi
from pianosdk.id.api.publisher_api import PublisherApi
from pianosdk.id.api.publisher_audit_api import PublisherAuditApi
from pianosdk.id.api.publisher_form_api import PublisherFormApi
from pianosdk.id.api.publisher_identity_api import PublisherIdentityApi
from pianosdk.id.api.publisher_identity_doi_api import PublisherIdentityDoiApi
from pianosdk.id.api.publisher_identity_set_api import PublisherIdentitySetApi
from pianosdk.id.api.publisher_import_custom_fields_api import PublisherImportCustomFieldsApi
from pianosdk.id.api.publisher_login_api import PublisherLoginApi
from pianosdk.id.api.publisher_login_social_api import PublisherLoginSocialApi
from pianosdk.id.api.publisher_reset_api import PublisherResetApi
from pianosdk.id.api.publisher_token_api import PublisherTokenApi
from pianosdk.id.api.publisher_userinfo_api import PublisherUserinfoApi
from pianosdk.id.api.publisher_users_api import PublisherUsersApi

from pianosdk.id.models.consent_model import ConsentModel
from pianosdk.id.models.custom_field_attribute_dto import CustomFieldAttributeDto
from pianosdk.id.models.custom_field_definition_dto import CustomFieldDefinitionDto
from pianosdk.id.models.custom_field_value_dto import CustomFieldValueDto
from pianosdk.id.models.import_cf_result import ImportCFResult
from pianosdk.id.models.input_stream import InputStream
from pianosdk.id.models.logout_response import LogoutResponse
from pianosdk.id.models.o_auth_request import OAuthRequest
from pianosdk.id.models.publisher_custom_field_response import PublisherCustomFieldResponse
from pianosdk.id.models.publisher_login_request import PublisherLoginRequest
from pianosdk.id.models.publisher_password_request import PublisherPasswordRequest
from pianosdk.id.models.publisher_register_request import PublisherRegisterRequest
from pianosdk.id.models.publisher_set_password_request import PublisherSetPasswordRequest
from pianosdk.id.models.publisher_user_profile_response import PublisherUserProfileResponse
from pianosdk.id.models.social_additional_input_request import SocialAdditionalInputRequest
from pianosdk.id.models.social_link_response import SocialLinkResponse
from pianosdk.id.models.social_linking_response import SocialLinkingResponse
from pianosdk.id.models.token_response import TokenResponse
from pianosdk.id.models.tooltip import Tooltip
from pianosdk.id.models.validator import Validator




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class DynamicTermAccessPeriod(BaseModel):
    term_id: Optional[str] = None
    period_id: Optional[str] = None
    removed: Optional[bool] = None
    access_end_date: Optional[datetime] = None


DynamicTermAccessPeriod.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class OfferTemplateContentField(BaseModel):
    content_field_id: Optional[str] = None
    offer_template_variant_id: Optional[str] = None
    offer_template_id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    deleted: Optional[bool] = None
    value: Optional[str] = None


OfferTemplateContentField.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.global_template_deployment_item import GlobalTemplateDeploymentItem
from typing import List


class GlobalTemplateDeploymentStatus(BaseModel):
    deployment_id: Optional[str] = None
    status: Optional[str] = None
    items: Optional['List[GlobalTemplateDeploymentItem]'] = None


GlobalTemplateDeploymentStatus.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class PriceDTO(BaseModel):
    currency_code: Optional[str] = None
    amount: Optional[float] = None
    currency_symbol: Optional[str] = None
    display: Optional[str] = None


PriceDTO.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ResourceDto(BaseModel):
    rid: Optional[str] = None
    aid: Optional[str] = None
    deleted: Optional[bool] = None
    disabled: Optional[bool] = None
    create_date: Optional[datetime] = None
    update_date: Optional[datetime] = None
    publish_date: Optional[datetime] = None
    name: Optional[str] = None
    description: Optional[str] = None
    image_url: Optional[str] = None
    type: Optional[str] = None
    type_label: Optional[str] = None
    bundle_type: Optional[str] = None
    bundle_type_label: Optional[str] = None
    purchase_url: Optional[str] = None
    resource_url: Optional[str] = None
    external_id: Optional[str] = None
    is_fbia_resource: Optional[bool] = None


ResourceDto.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.offer_template_version import OfferTemplateVersion


class PublisherOfferTemplateInheritedApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def count_inherited_templates(self, aid: str, offer_template_id: str) -> ApiResponse[int]:
        _url_path = '/api/v3/publisher/offer/template/inherited/count'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'offer_template_id': _encode_parameter(offer_template_id)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, int)
        return _result

    def update_inherited_template(self, aid: str, offer_template_id: str, content_field_list: str = None, history_comment: str = None, is_validate: bool = None) -> ApiResponse[OfferTemplateVersion]:
        _url_path = '/api/v3/publisher/offer/template/inherited/update'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'offer_template_id': _encode_parameter(offer_template_id),
            'content_field_list': _encode_parameter(content_field_list),
            'history_comment': _encode_parameter(history_comment),
            'is_validate': _encode_parameter(is_validate)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, OfferTemplateVersion)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.source_term_change_variants import SourceTermChangeVariants
from pianosdk.publisher.models.target_term_change_variants import TargetTermChangeVariants
from pianosdk.publisher.models.upgrade_offer_variant import UpgradeOfferVariant
from typing import List


class TermChangeVariants(BaseModel):
    source_term_change_variants: Optional['SourceTermChangeVariants'] = None
    target_term_change_variants: Optional['TargetTermChangeVariants'] = None
    upgrade_offer_variants: Optional['List[UpgradeOfferVariant]'] = None
    show_options: Optional[List[str]] = None


TermChangeVariants.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.error_code import ErrorCode
from pianosdk.publisher.models.error_codes import ErrorCodes
from typing import Any
from typing import List


class Result(BaseModel):
    errors: Optional['List[ErrorCode]'] = None
    error: Optional['ErrorCode'] = None
    error_codes: Optional['ErrorCodes'] = None
    ok: Optional[bool] = None
    or_fail: Optional['Any'] = None
    error_as_string: Optional[str] = None


Result.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.country_simple_model import CountrySimpleModel
from pianosdk.publisher.models.region_simple_model import RegionSimpleModel


class UserBillingAddress(BaseModel):
    address_line1: Optional[str] = None
    address_line2: Optional[str] = None
    address_line3: Optional[str] = None
    country: Optional['CountrySimpleModel'] = None
    region: Optional['RegionSimpleModel'] = None
    region_name: Optional[str] = None
    city: Optional[str] = None
    postal_code: Optional[str] = None
    type: Optional[str] = None
    verified: Optional[str] = None
    address_pub_id: Optional[str] = None


UserBillingAddress.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.region import Region
from typing import List


class Country(BaseModel):
    country_name: Optional[str] = None
    country_code: Optional[str] = None
    country_id: Optional[str] = None
    regions: Optional['List[Region]'] = None


Country.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class SubscriptionMigrationHistoryDTO(BaseModel):
    subscription_id: Optional[str] = None
    schedule_time: Optional[datetime] = None
    from_term_name: Optional[str] = None
    is_migrated: Optional[bool] = None


SubscriptionMigrationHistoryDTO.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ExperienceVersion(BaseModel):
    experience_id: Optional[str] = None
    version: Optional[int] = None
    minor_version: Optional[int] = None
    major_version: Optional[int] = None
    committed: Optional[bool] = None
    committed_date: Optional[datetime] = None
    revision_notes: Optional[str] = None


ExperienceVersion.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.configuration_property_metadata import ConfigurationPropertyMetadata
from typing import Any
from typing import List


class PpcWebModel(BaseModel):
    name: Optional[str] = None
    title: Optional[str] = None
    source_id: Optional[str] = None
    properties: Optional['List[ConfigurationPropertyMetadata]'] = None
    configuration_attributes: Optional['Any'] = None


PpcWebModel.model_rebuild()
